@@ -35,7 +35,7 @@ TEXT_FILETYPE = ('text/plain',
 IMG_FILETYPE = ('image/jpeg', 'image/png', 'image/gif', 'image/x-ms-bmp')
 P7M_FILETYPE = ('application/pkcs7-mime',)
 SIGNED_FILETYPE = PDF_FILETYPE + P7M_FILETYPE
-PERMITTED_UPLOAD_FILETYPE = TEXT_FILETYPE + DATA + PDF_FILETYPE + IMG_FILETYPE
+PERMITTED_UPLOAD_FILETYPE = TEXT_FILETYPE + DATA_FILETYPE + SIGNED_FILETYPE + IMG_FILETYPE
 
 # maximum permitted filename lengh in attachments, uploads
 ATTACH_NAME_MAX_LEN = 50
